@@ -2,8 +2,7 @@
 
 from typing import Optional
 
-from pydantic import BaseModel
-
+from ..base_model import BaseModel
 from .state import UserState
 
 
